# Changelogs

## Latest Changes

## 0.1.0

### Features

- :dart: feat: add write all changelog option for re-write all logs to new file. (_2023-10-17_)
- :dart: feat: add tag from version cli for create git tag by __about__. (_2023-10-06_)

### Code Changes

- :construction: refactored: change the name of cli commands. (_2023-10-17_)
- :construction: refactored: change value on BumpVerConf obj in setting file. (_2023-10-16_)
- :construction: refactored: change print function to click.echo that recommend by click. (_2023-10-16_)
- :construction: refactored: 📦 bump mypy from 1.5.1 to 1.6.0 (#13) (_2023-10-16_)
- :construction: refactored: 📦 bump pre-commit from 3.4.0 to 3.5.0 (_2023-10-16_)
- :construction: refactored: 📦 bump coverage[toml] from 7.3.1 to 7.3.2 (_2023-10-09_)

### Documents

- :page_facing_up: docs: update doc-string on bump command. (_2023-10-17_)
- :page_facing_up: docs: update API commands on README file. (_2023-10-17_)

## 0.0.4

### Features

- :dart: feat: add git cmd for sync deleted tag from remote. (_2023-10-06_)
- :dart: feat: add init-conf Git command for set name and email on local. (_2023-09-14_)

### Code Changes

- :bookmark: Bump up to version 0.0.3 -> 0.0.4. (_2023-10-06_)
- :test_tube: test: update test-case for git cli. (_2023-10-06_)
- :construction: refactored: change test-case name and improve perf in git. (_2023-10-06_)
- :construction: refactored: add detail syntax for git commands. (_2023-09-26_)

### Documents

- :page_facing_up: docs: update feature on README. (_2023-10-06_)
- :page_facing_up: docs: add comment statement on cli command. (_2023-10-06_)
- :page_facing_up: docs: add doc-string and license message. (_2023-10-02_)
- :page_facing_up: docs: update CONTRIBUTING file for revise name and email in git. (_2023-09-14_)

### Fix Bugs

- :gear: fixed: add value for the Level enum before return. (_2023-10-06_)
- :gear: fixed: change make_color function that handle value of Enum. (_2023-10-06_)

## 0.0.3

### Features

- :dart: feat: add CONTRIBUTING file to this project. (_2023-09-12_)
- :dart: feat: add CONTRIBUTING file to this project. (_2023-09-12_)

### Code Changes

- :construction: refactor: [pre-commit.ci] auto fixes from pre-commit.com hooks (_2023-09-12_)
- :construction: refactor: [pre-commit.ci] pre-commit autoupdate (_2023-09-12_)
- :test_tube: test: add test case for git cli. (_2023-09-09_)
- :test_tube: test: add test case for git cli. (_2023-09-09_)
- :construction: refactor: ⬆ bump actions/checkout from 3 to 4 (_2023-09-08_)
- :test_tube: test: add parameter for pre-commit ci workflow. (_2023-09-08_)

### Documents

- :page_facing_up: docs: edit README file and add more information of this project. (_2023-09-12_)

### Build & Workflow

- :toolbox: build: add skip pytest from local repo of pre-commit config. (_2023-09-12_)
- :toolbox: build: add pip ecosystem in dependabot. (_2023-09-08_)
- :package: build: create dependabot.yml (_2023-09-08_)

## 0.0.2

### Documents

- :page_facing_up: docs: update README and deps package on pyproject. (_2023-09-08_)

### Build & Workflow

- :toolbox: build: change install deps package GitHub workflow. (_2023-09-08_)

## 0.0.1

### Features

- :dart: feat: first initial the main code to this repo. (_2023-09-08_)

### Code Changes

- :construction: refactored: change version of inital stage to 0.0.0. (_2023-09-08_)
- :construction: refactor: Initial commit (_2023-09-08_)

### Documents

- :page_facing_up: docs: edit name in README file and remove un-use deps package. (_2023-09-08_)

### Build & Workflow

- :toolbox: build: add GitHub workflows for test and publish. (_2023-09-08_)
